@@ -150,33 +150,18 @@ where
         }
       }
 
-      Branch2 { left, middle, .. } => {
-        if let Some(pos) = left.find_index(f.clone()) {
-          return Some(pos);
-        }
+      Branch2 { left, middle, .. } => left
+        .find_index(f.to_owned())
+        .or_else(|| middle.find_index(f.to_owned()).map(|pos| pos + left.len() as i64)),
 
-        if let Some(pos) = middle.find_index(f.clone()) {
-          return Some(pos + left.len() as i64);
-        }
-
-        None
-      }
-
-      Branch3 { left, middle, right, .. } => {
-        if let Some(pos) = left.find_index(f.clone()) {
-          return Some(pos);
-        }
-
-        if let Some(pos) = middle.find_index(f.clone()) {
-          return Some(pos + left.len() as i64);
-        }
-
-        if let Some(pos) = right.find_index(f.clone()) {
-          return Some(pos + (left.len() as i64) + (middle.len() as i64));
-        }
-
-        None
-      }
+      Branch3 { left, middle, right, .. } => left
+        .find_index(f.to_owned())
+        .or_else(|| middle.find_index(f.to_owned()).map(|pos| pos + left.len() as i64))
+        .or_else(|| {
+          right
+            .find_index(f.to_owned())
+            .map(|pos| pos + left.len() as i64 + middle.len() as i64)
+        }),
     }
   }
 
@@ -189,22 +174,11 @@ where
           None
         }
       }
-      Branch2 { left, middle, .. } => {
-        if let Some(pos) = left.index_of(item) {
-          Some(pos)
-        } else {
-          middle.index_of(item).map(|pos| pos + left.len())
-        }
-      }
-      Branch3 { left, middle, right, .. } => {
-        if let Some(pos) = left.index_of(item) {
-          Some(pos)
-        } else if let Some(pos) = middle.index_of(item) {
-          Some(pos + left.len())
-        } else {
-          right.index_of(item).map(|pos| pos + left.len() + middle.len())
-        }
-      }
+      Branch2 { left, middle, .. } => left.index_of(item).or_else(|| middle.index_of(item).map(|pos| pos + left.len())),
+      Branch3 { left, middle, right, .. } => left
+        .index_of(item)
+        .or_else(|| middle.index_of(item).map(|pos| pos + left.len()))
+        .or_else(|| right.index_of(item).map(|pos| pos + left.len() + middle.len())),
     }
   }
 
@@ -261,14 +235,15 @@ where
         } else if idx < base + middle.len() {
           middle.ref_get(idx - base)
         } else {
-          right.ref_get(idx - left.len() - middle.len())
+          right.ref_get(idx - base - middle.len())
         }
       }
       Branch2 { left, middle, .. } => {
-        if idx < left.len() {
+        let base = left.len();
+        if idx < base {
           left.ref_get(idx)
         } else {
-          middle.ref_get(idx - left.len())
+          middle.ref_get(idx - base)
         }
       }
       Leaf(value) => Some(value),
@@ -418,7 +393,7 @@ where
             size: size.to_owned(),
             left: left.to_owned(),
             middle: middle.to_owned(),
-            right: Arc::new(changed_branch.to_owned()),
+            right: Arc::new(changed_branch),
           })
         }
       }
@@ -521,7 +496,7 @@ where
             size: *size - 1,
             left: left.to_owned(),
             middle: middle.to_owned(),
-            right: Arc::new(changed_branch.to_owned()),
+            right: Arc::new(changed_branch),
           })
         }
       }
@@ -761,7 +736,7 @@ where
           let changed_branch = left.insert(idx, item, after)?;
           Ok(Branch3 {
             size: *size + 1,
-            left: Arc::new(changed_branch.to_owned()),
+            left: Arc::new(changed_branch),
             middle: middle.to_owned(),
             right: right.to_owned(),
           })
@@ -771,7 +746,7 @@ where
           Ok(Branch3 {
             size: *size + 1,
             left: left.to_owned(),
-            middle: Arc::new(changed_branch.to_owned()),
+            middle: Arc::new(changed_branch),
             right: right.to_owned(),
           })
         } else {
@@ -781,7 +756,7 @@ where
             size: *size + 1,
             left: left.to_owned(),
             middle: middle.to_owned(),
-            right: Arc::new(changed_branch.to_owned()),
+            right: Arc::new(changed_branch),
           })
         }
       }
@@ -806,7 +781,7 @@ where
   pub fn prepend(&self, item: T) -> Self {
     match self.insert(0, item, false) {
       Ok(v) => v,
-      Err(e) => unreachable!(e),
+      Err(e) => unreachable!("{}", e),
     }
   }
   pub fn push(&self, item: T) -> Self {
@@ -815,7 +790,7 @@ where
   pub fn append(&self, item: T) -> Self {
     match self.insert(self.len() - 1, item, true) {
       Ok(v) => v,
-      Err(e) => unreachable!(e),
+      Err(e) => unreachable!("{}", e),
     }
   }
 
@@ -946,8 +921,8 @@ where
               ..
             } => Branch3 {
               size: size - 1,
-              left: b_left.to_owned(),
-              middle: b_middle.to_owned(),
+              left: b_left,
+              middle: b_middle,
               right: middle.to_owned(),
             },
             Branch3 {
@@ -963,7 +938,7 @@ where
               };
               Branch3 {
                 size: size - 1,
-                left: b_left.to_owned(),
+                left: b_left,
                 middle: Arc::new(internal_branch),
                 right: middle.to_owned(),
               }
